@@ -86,17 +86,34 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #define PPM_O_WRONLY	(1 << 1)	/* Open for writing only */
 #define PPM_O_RDWR	(PPM_O_RDONLY | PPM_O_WRONLY)	/* Open for reading and writing */
 #define PPM_O_CREAT	(1 << 2)	/* Create a new file if it doesn't exist. */
-#define PPM_O_APPEND (1 << 3)	/* If set, the file offset shall be set to the end of the file prior to each write. */
+#define PPM_O_APPEND	(1 << 3)	/* If set, the file offset shall be set to the end of the file prior to each write. */
 #define PPM_O_DSYNC	(1 << 4)
 #define PPM_O_EXCL	(1 << 5)
 #define PPM_O_NONBLOCK	(1 << 6)
 #define PPM_O_SYNC	(1 << 7)
 #define PPM_O_TRUNC	(1 << 8)
-#define PPM_O_DIRECT (1 << 9)
+#define PPM_O_DIRECT	(1 << 9)
 #define PPM_O_DIRECTORY (1 << 10)
 #define PPM_O_LARGEFILE (1 << 11)
 #define PPM_O_CLOEXEC	(1 << 12)
 
+/*
+ * File modes
+ */
+#define PPM_S_NONE  0
+#define PPM_S_IXOTH (1 << 0)
+#define PPM_S_IWOTH (1 << 1)
+#define PPM_S_IROTH (1 << 2)
+#define PPM_S_IXGRP (1 << 3)
+#define PPM_S_IWGRP (1 << 4)
+#define PPM_S_IRGRP (1 << 5)
+#define PPM_S_IXUSR (1 << 6)
+#define PPM_S_IWUSR (1 << 7)
+#define PPM_S_IRUSR (1 << 8)
+#define PPM_S_ISVTX (1 << 9)
+#define PPM_S_ISGID (1 << 10)
+#define PPM_S_ISUID (1 << 11)
+
 /*
  * flock() flags
  */
@@ -285,6 +302,9 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #define PPM_FCNTL_F_NOTIFY 27
 #define PPM_FCNTL_F_SETPIPE_SZ 28
 #define PPM_FCNTL_F_GETPIPE_SZ 29
+#define PPM_FCNTL_F_OFD_GETLK 30
+#define PPM_FCNTL_F_OFD_SETLK 31
+#define PPM_FCNTL_F_OFD_SETLKW 32
 
  /*
  * ptrace requests
@@ -778,7 +798,9 @@ enum ppm_event_type {
 	PPME_NOTIFICATION_X = 281,
 	PPME_SYSCALL_EXECVE_17_E = 282,
 	PPME_SYSCALL_EXECVE_17_X = 283,
-	PPM_EVENT_MAX = 284
+	PPME_SYSCALL_UNSHARE_E = 284,
+	PPME_SYSCALL_UNSHARE_X = 285,
+	PPM_EVENT_MAX = 286
 };
 /*@}*/
 
@@ -1192,10 +1214,11 @@ enum ppm_param_type {
 enum ppm_print_format {
 	PF_NA = 0,
 	PF_DEC = 1,	/* decimal */
-	PF_HEX = 2,	/* hexadecima */
+	PF_HEX = 2,	/* hexadecimal */
 	PF_10_PADDED_DEC = 3, /* decimal padded to 10 digits, useful to print the fractional part of a ns timestamp */
 	PF_ID = 4,
 	PF_DIR = 5,
+	PF_OCT = 6,	/* octal */
 };
 
 /*!
