@@ -59,7 +59,7 @@ scap_t* scap_open_live_int(char *error,
 static uint32_t get_max_consumers()
 {
 	uint32_t max;
-	FILE *pfile = fopen("/sys/module/sysdig_probe/parameters/max_consumers", "r");
+	FILE *pfile = fopen("/sys/module/" PROBE_DEVICE_NAME "_probe/parameters/max_consumers", "r");
 	if(pfile != NULL)
 	{
 		int w = fscanf(pfile, "%"PRIu32, &max);
@@ -203,7 +203,7 @@ scap_t* scap_open_live_int(char *error,
 			else if(errno == EBUSY)
 			{
 				uint32_t curr_max_consumers = get_max_consumers();
-				snprintf(error, SCAP_LASTERR_SIZE, "Too many sysdig instances attached to device %s. Current value for /sys/module/sysdig_probe/parameters/max_consumers is '%"PRIu32"'.", filename, curr_max_consumers);
+				snprintf(error, SCAP_LASTERR_SIZE, "Too many sysdig instances attached to device %s. Current value for /sys/module/" PROBE_DEVICE_NAME "_probe/parameters/max_consumers is '%"PRIu32"'.", filename, curr_max_consumers);
 			}
 			else
 			{
@@ -214,6 +214,13 @@ scap_t* scap_open_live_int(char *error,
 			return NULL;
 		}
 
+		// Set close-on-exec for the fd
+		if (fcntl(handle->m_devs[j].m_fd, F_SETFD, FD_CLOEXEC) == -1) {
+			snprintf(error, SCAP_LASTERR_SIZE, "Can not set close-on-exec flag for fd for device %s (%s)", filename, strerror(errno));
+			scap_close(handle);
+			return NULL;
+		}
+
 		//
 		// Map the ring buffer
 		//
@@ -288,7 +295,7 @@ scap_t* scap_open_live_int(char *error,
 }
 #endif // HAS_CAPTURE
 
-scap_t* scap_open_offline_int(const char* fname,
+scap_t* scap_open_offline_int(gzFile gzfile,
 							  char *error,
 							  proc_entry_callback proc_callback,
 							  void* proc_callback_context,
@@ -334,16 +341,7 @@ scap_t* scap_open_offline_int(const char* fname,
 		return NULL;
 	}
 
-	//
-	// Open the file
-	//
-	handle->m_file = gzopen(fname, "rb");
-	if(handle->m_file == NULL)
-	{
-		snprintf(error, SCAP_LASTERR_SIZE, "can't open file %s", fname);
-		scap_close(handle);
-		return NULL;
-	}
+	handle->m_file = gzfile;
 
 	//
 	// If this is a merged file, we might have to move the read offset to the next section
@@ -358,7 +356,7 @@ scap_t* scap_open_offline_int(const char* fname,
 	//
 	if(scap_read_init(handle, handle->m_file) != SCAP_SUCCESS)
 	{
-		snprintf(error, SCAP_LASTERR_SIZE, "%s", scap_getlasterr(handle));
+		snprintf(error, SCAP_LASTERR_SIZE, "Could not initialize reader: %s", scap_getlasterr(handle));
 		scap_close(handle);
 		return NULL;
 	}
@@ -387,7 +385,26 @@ scap_t* scap_open_offline_int(const char* fname,
 
 scap_t* scap_open_offline(const char* fname, char *error)
 {
-	return scap_open_offline_int(fname, error, NULL, NULL, true, 0);
+	gzFile gzfile = gzopen(fname, "rb");
+	if(gzfile == NULL)
+	{
+		snprintf(error, SCAP_LASTERR_SIZE, "can't open file %s", fname);
+		return NULL;
+	}
+
+	return scap_open_offline_int(gzfile, error, NULL, NULL, true, 0);
+}
+
+scap_t* scap_open_offline_fd(int fd, char *error)
+{
+	gzFile gzfile = gzdopen(fd, "rb");
+	if(gzfile == NULL)
+	{
+		snprintf(error, SCAP_LASTERR_SIZE, "can't open fd %d", fd);
+		return NULL;
+	}
+
+	return scap_open_offline_int(gzfile, error, NULL, NULL, true, 0);
 }
 
 scap_t* scap_open_live(char *error)
@@ -494,9 +511,35 @@ scap_t* scap_open(scap_open_args args, char *error)
 	switch(args.mode)
 	{
 	case SCAP_MODE_CAPTURE:
-		return scap_open_offline_int(args.fname, error,
+	{
+		gzFile gzfile;
+
+		if(args.fd != 0)
+		{
+			gzfile = gzdopen(args.fd, "rb");
+		}
+		else
+		{
+			gzfile = gzopen(args.fname, "rb");
+		}
+
+		if(gzfile == NULL)
+		{
+			if(args.fd != 0)
+			{
+				snprintf(error, SCAP_LASTERR_SIZE, "can't open fd %d", args.fd);
+			}
+			else
+			{
+				snprintf(error, SCAP_LASTERR_SIZE, "can't open file %s", args.fname);
+			}
+			return NULL;
+		}
+
+		return scap_open_offline_int(gzfile, error,
 									 args.proc_callback, args.proc_callback_context,
 									 args.import_users, args.start_offset);
+	}
 	case SCAP_MODE_LIVE:
 		return scap_open_live_int(error, args.proc_callback,
 								  args.proc_callback_context,
@@ -523,24 +566,24 @@ void scap_close(scap_t* handle)
 
 		ASSERT(handle->m_file == NULL);
 
-		//
-		// Destroy all the device descriptors
-		//
-		for(j = 0; j < handle->m_ndevs; j++)
-		{
-			if(handle->m_devs[j].m_buffer != MAP_FAILED)
-			{
-				munmap(handle->m_devs[j].m_bufinfo, sizeof(struct ppm_ring_buffer_info));
-				munmap(handle->m_devs[j].m_buffer, RING_BUF_SIZE * 2);
-				close(handle->m_devs[j].m_fd);
-			}
-		}
-
-		//
-		// Free the memory
-		//
 		if(handle->m_devs != NULL)
 		{
+			//
+			// Destroy all the device descriptors
+			//
+			for(j = 0; j < handle->m_ndevs; j++)
+			{
+				if(handle->m_devs[j].m_buffer != MAP_FAILED)
+				{
+				    munmap(handle->m_devs[j].m_bufinfo, sizeof(struct ppm_ring_buffer_info));
+				    munmap(handle->m_devs[j].m_buffer, RING_BUF_SIZE * 2);
+				    close(handle->m_devs[j].m_fd);
+				}
+			}
+
+			//
+			// Free the memory
+			//
 			free(handle->m_devs);
 		}
 #endif // HAS_CAPTURE
@@ -907,11 +950,13 @@ int32_t scap_get_stats(scap_t* handle, OUT scap_stats* stats)
 
 	stats->n_evts = 0;
 	stats->n_drops = 0;
+	stats->n_drops_buffer = 0;
 	stats->n_preemptions = 0;
 
 	for(j = 0; j < handle->m_ndevs; j++)
 	{
 		stats->n_evts += handle->m_devs[j].m_bufinfo->n_evts;
+		stats->n_drops_buffer += handle->m_devs[j].m_bufinfo->n_drops_buffer;
 		stats->n_drops += handle->m_devs[j].m_bufinfo->n_drops_buffer +
 			handle->m_devs[j].m_bufinfo->n_drops_pf;
 		stats->n_preemptions += handle->m_devs[j].m_bufinfo->n_preemptions;
