@@ -83,6 +83,7 @@ typedef struct scap_stats
 {
 	uint64_t n_evts; ///< Total number of events that were received by the driver.
 	uint64_t n_drops; ///< Number of dropped events.
+	uint64_t n_drops_buffer; ///< Number of dropped events caused by full buffer.
 	uint64_t n_preemptions; ///< Number of preemptions.
 }scap_stats;
 
@@ -122,7 +123,9 @@ typedef enum scap_fd_type
 	SCAP_FD_SIGNALFD = 11,
 	SCAP_FD_EVENTPOLL = 12,
 	SCAP_FD_INOTIFY = 13,
-	SCAP_FD_TIMERFD = 14
+	SCAP_FD_TIMERFD = 14,
+	SCAP_FD_NETLINK = 15,
+	SCAP_FD_FILE_V2 = 16
 }scap_fd_type;
 
 /*!
@@ -182,6 +185,11 @@ typedef struct scap_fdinfo
 		  	uint64_t destination; ///< Destination socket endpoint
 			char fname[SCAP_MAX_PATH_SIZE]; ///< Name associated to this unix socket
 		} unix_socket_info; ///< Information specific to unix sockets
+		struct
+		{
+			uint32_t open_flags; ///< Flags associated with the file
+			char fname[SCAP_MAX_PATH_SIZE]; ///< Name associated to this file
+		} regularinfo; ///< Information specific to regular files
 		char fname[SCAP_MAX_PATH_SIZE];  ///< The name for file system FDs
 	}info;
 	UT_hash_handle hh; ///< makes this structure hashable
@@ -243,6 +251,7 @@ typedef enum {
 typedef struct scap_open_args
 {
 	scap_mode_t mode;
+	int fd; // If non-zero, will be used instead of fname.
 	const char* fname; ///< The name of the file to open. NULL for live captures.
 	proc_entry_callback proc_callback; ///< Callback to be invoked for each thread/fd that is extracted from /proc, or NULL if no callback is needed.
 	void* proc_callback_context; ///< Opaque pointer that will be included in the calls to proc_callback. Ignored if proc_callback is NULL.
@@ -496,6 +505,17 @@ scap_t* scap_open_live(char *error);
 */
 scap_t* scap_open_offline(const char* fname, char *error);
 
+/*!
+  \brief Start an event capture from an already opened file descriptor.
+
+  \param fd The fd to use.
+  \param error Pointer to a buffer that will contain the error string in case the
+    function fails. The buffer must have size SCAP_LASTERR_SIZE.
+
+  \return The capture instance handle in case of success. NULL in case of failure.
+*/
+scap_t* scap_open_offline_fd(int fd, char *error);
+
 /*!
   \brief Advanced function to start a capture.
 
@@ -575,6 +595,13 @@ uint64_t scap_event_get_ts(scap_evt* e);
 */
 uint64_t scap_event_get_num(scap_t* handle);
 
+/*!
+  \brief Reset the event count to 0.
+
+  \param handle Handle to the capture instance.
+*/
+void scap_event_reset_count(scap_t* handle);
+
 /*!
   \brief Return the meta-information describing the given event
 
@@ -611,6 +638,16 @@ int64_t scap_get_readfile_offset(scap_t* handle);
 */
 scap_dumper_t* scap_dump_open(scap_t *handle, const char *fname, compression_mode compress);
 
+/*!
+  \brief Open a tracefile for writing, using the provided fd.
+
+  \param handle Handle to the capture instance.
+  \param fd A file descriptor to which the dumper will write
+
+  \return Dump handle that can be used to identify this specific dump instance.
+*/
+scap_dumper_t* scap_dump_open_fd(scap_t *handle, int fd, compression_mode compress, bool skip_proc_scan);
+
 /*!
   \brief Close a tracefile.
 
@@ -626,6 +663,15 @@ void scap_dump_close(scap_dumper_t *d);
 */
 int64_t scap_dump_get_offset(scap_dumper_t *d);
 
+/*!
+  \brief Return the position for the next write to a tracefile.
+         This uses gztell, while scap_dump_get_offset uses gzoffset.
+
+  \param d The dump handle, returned by \ref scap_dump_open
+  \return The next write position.
+*/
+int64_t scap_dump_ftell(scap_dumper_t *d);
+
 /*!
   \brief Flush all pending output into the file.
 
@@ -890,6 +936,10 @@ int32_t scap_fd_add(scap_threadinfo* tinfo, uint64_t fd, scap_fdinfo* fdinfo);
 scap_dumper_t *scap_memory_dump_open(scap_t *handle, uint8_t* targetbuf, uint64_t targetbufsize);
 int32_t compr(uint8_t* dest, uint64_t* destlen, const uint8_t* source, uint64_t sourcelen, int level);
 uint8_t* scap_get_memorydumper_curpos(scap_dumper_t *d);
+int32_t scap_write_proc_fds(scap_t *handle, struct scap_threadinfo *tinfo, scap_dumper_t *d);
+int32_t scap_write_proclist_header(scap_t *handle, scap_dumper_t *d, uint32_t totlen);
+int32_t scap_write_proclist_trailer(scap_t *handle, scap_dumper_t *d, uint32_t totlen);
+int32_t scap_write_proclist_entry(scap_t *handle, scap_dumper_t *d, struct scap_threadinfo *tinfo);
 
 #ifdef __cplusplus
 }
