@@ -310,9 +310,10 @@ int32_t scap_proc_fill_cgroups(struct scap_threadinfo* tinfo, const char* procdi
 		char* token;
 		char* subsys_list;
 		char* cgroup;
+		char* scratch;
 
 		// id
-		token = strtok(line, ":");
+		token = strtok_r(line, ":", &scratch);
 		if(token == NULL)
 		{
 			ASSERT(false);
@@ -321,7 +322,7 @@ int32_t scap_proc_fill_cgroups(struct scap_threadinfo* tinfo, const char* procdi
 		}
 
 		// subsys
-		subsys_list = strtok(NULL, ":");
+		subsys_list = strtok_r(NULL, ":", &scratch);
 		if(subsys_list == NULL)
 		{
 			ASSERT(false);
@@ -329,6 +330,16 @@ int32_t scap_proc_fill_cgroups(struct scap_threadinfo* tinfo, const char* procdi
 			return SCAP_FAILURE;
 		}
 
+		// Hack to detect empty fields, because strtok does not support it
+		// strsep() should be used to fix this but it's not available
+		// on CentOS 6 (has been added from Glibc 2.19)
+		if(subsys_list-token-strlen(token) > 1)
+		{
+			// skip cgroups like this:
+			// 0::/init.scope
+			continue;
+		}
+
 		// transient cgroup
 		if(strncmp(subsys_list, "name=", sizeof("name=") - 1) == 0)
 		{
@@ -336,7 +347,7 @@ int32_t scap_proc_fill_cgroups(struct scap_threadinfo* tinfo, const char* procdi
 		}
 
 		// cgroup
-		cgroup = strtok(NULL, ":");
+		cgroup = strtok_r(NULL, ":", &scratch);
 		if(cgroup == NULL)
 		{
 			ASSERT(false);
@@ -347,7 +358,7 @@ int32_t scap_proc_fill_cgroups(struct scap_threadinfo* tinfo, const char* procdi
 		// remove the \n
 		cgroup[strlen(cgroup) - 1] = 0;
 
-		while((token = strtok(subsys_list, ",")) != NULL)
+		while((token = strtok_r(subsys_list, ",", &scratch)) != NULL)
 		{
 			subsys_list = NULL;
 			if(strlen(cgroup) + 1 + strlen(token) + 1 > SCAP_MAX_CGROUPS_SIZE - tinfo->cgroups_len)
