@@ -109,6 +109,7 @@ uint32_t lua_cbacks::rawval_to_lua_stack(lua_State *ls, uint8_t* rawval, const f
 			lua_pushnumber(ls, *(double*)rawval);
 			return 1;
 		case PT_CHARBUF:
+		case PT_FSPATH:
 			lua_pushlstring(ls, (char*)rawval, len);
 			return 1;
 		case PT_BYTEBUF:
@@ -832,12 +833,12 @@ int lua_cbacks::get_thread_table(lua_State *ls)
 		//
 		lua_pushstring(ls, "env");
 
-		vector<string>* env = &(it->second.m_env);
+		const auto& env = it->second.get_env();
 		lua_newtable(ls);
-		for(j = 0; j < env->size(); j++)
+		for(j = 0; j < env.size(); j++)
 		{
 			lua_pushinteger(ls, j + 1);
-			lua_pushstring(ls, env->at(j).c_str());
+			lua_pushstring(ls, env.at(j).c_str());
 			lua_settable(ls, -3);
 		}
 		lua_settable(ls,-3);
