@@ -231,6 +231,7 @@ string sinsp_container_manager::get_mesos_task_id(const string& container_id)
 
 bool sinsp_container_manager::resolve_container(sinsp_threadinfo* tinfo, bool query_os_for_missing_info)
 {
+
 	ASSERT(tinfo);
 	bool valid_id = false;
 	sinsp_container_info container_info;
@@ -355,27 +356,60 @@ bool sinsp_container_manager::resolve_container(sinsp_threadinfo* tinfo, bool qu
 		//
 		// systemd rkt
 		//
-		pos = cgroup.find("machine-rkt\\x2d");
-		if(pos != string::npos)
+		// rkt cgroups
+		// 1. /system.slice/k8s_d1efb75a-ad42-458e-af65-2b378f42173f.service/system.slice/redis.service
+		// 2. /machine.slice/machine-rkt\x2dc508ad4c\x2d7fa4\x2d4513\x2d9d53\x2d007628003805.scope/system.slice/redis.service
+		static const string COREOS_PODID_VAR = "container_uuid=";
+		static const string SYSTEMD_UUID_ARG = "--uuid=";
+		static const string SERVICE_SUFFIX = ".service";
+		if(cgroup.rfind(SERVICE_SUFFIX) == cgroup.size() - SERVICE_SUFFIX.size())
 		{
-			string::size_type service_pos = cgroup.find("/", pos + 1);
-			if (service_pos == string::npos)
-				continue;
+			// check if there is a parent with pod uuid var
+			sinsp_threadinfo::visitor_func_t visitor = [&rkt_podid](sinsp_threadinfo* ptinfo)
+			{
+				for(const auto& env_var : ptinfo->get_env())
+				{
+					auto container_uuid_pos = env_var.find(COREOS_PODID_VAR);
+					if(container_uuid_pos == 0)
+					{
+						rkt_podid = env_var.substr(COREOS_PODID_VAR.size());
+						return false;
+					}
+				}
+				for(const auto& arg : ptinfo->m_args)
+				{
+					if(arg.find(SYSTEMD_UUID_ARG) != string::npos)
+					{
+						rkt_podid = arg.substr(SYSTEMD_UUID_ARG.size());
+						return false;
+					}
+				}
+				return true;
+			};
+			tinfo->traverse_parent_state(visitor);
 
-			string::size_type appname_pos = cgroup.find("/", service_pos + 1);
-			string::size_type appname_pos2 = cgroup.find(".", appname_pos + 1);
-			if (appname_pos == string::npos || appname_pos2 == string::npos)
-				continue;
-			rkt_appname = cgroup.substr(appname_pos + 1, appname_pos2 - appname_pos - 1);
-			if (rkt_appname.substr(0, 7) == "systemd" || rkt_appname.substr(0, 8) == "/machine")
-				continue;
-			rkt_podid = cgroup.substr(pos + sizeof("machine-rkt\\x2d") - 1, 48);
-			replace_in_place(rkt_podid, "\\x2d", "-");
-			container_info.m_type = CT_RKT;
-			container_info.m_id = rkt_podid + ":" + rkt_appname;
-			container_info.m_name = rkt_appname;
-			valid_id = true;
-			break;
+			if(!rkt_podid.empty())
+			{
+				auto last_slash = cgroup.find_last_of("/");
+				rkt_appname = cgroup.substr(last_slash + 1, cgroup.size() - last_slash - SERVICE_SUFFIX.size() - 1);
+				
+				char image_manifest_path[SCAP_MAX_PATH_SIZE];
+				snprintf(image_manifest_path, sizeof(image_manifest_path), "%s/var/lib/rkt/pods/run/%s/appsinfo/%s/manifest", scap_get_host_root(), rkt_podid.c_str(), rkt_appname.c_str());
+
+				// First lookup if the container exists in our table, otherwise only if we are live check if it has
+				// an entry in /var/lib/rkt. In capture mode only the former will be used.
+				// In live mode former will be used only if we already hit that container
+				if( m_containers.find(rkt_podid + ":" + rkt_appname) != m_containers.end() ||
+					(query_os_for_missing_info && access(image_manifest_path, F_OK) == 0)
+					)
+				{
+					container_info.m_type = CT_RKT;
+					container_info.m_id = rkt_podid + ":" + rkt_appname;
+					container_info.m_name = rkt_appname;
+					valid_id = true;
+					break;
+				} 
+			}
 		}
 	}
 
@@ -385,6 +419,8 @@ bool sinsp_container_manager::resolve_container(sinsp_threadinfo* tinfo, bool qu
 	{
 		// Try parsing from process root,
 		// Strings used to detect rkt stage1-cores pods
+		// TODO: detecting stage1-coreos rkt pods in this way is deprecated
+		// we can remove it in the future
 		static const string COREOS_PREFIX = "/opt/stage2/";
 		static const string COREOS_APP_SUFFIX = "/rootfs";
 		static const string COREOS_PODID_VAR = "container_uuid=";
@@ -400,7 +436,7 @@ bool sinsp_container_manager::resolve_container(sinsp_threadinfo* tinfo, bool qu
 
 				sinsp_threadinfo::visitor_func_t visitor = [&rkt_podid, &container_info, &rkt_appname, &valid_id] (sinsp_threadinfo *ptinfo)
 				{
-					for(const auto& env_var : ptinfo->m_env)
+					for(const auto& env_var : ptinfo->get_env())
 					{
 						auto container_uuid_pos = env_var.find(COREOS_PODID_VAR);
 						if(container_uuid_pos == 0)
@@ -494,7 +530,7 @@ bool sinsp_container_manager::resolve_container(sinsp_threadinfo* tinfo, bool qu
 					ASSERT(false);
 			}
 
-			m_containers.insert(std::make_pair(container_info.m_id, container_info));
+			add_container(container_info);
 			if(container_to_sinsp_event(container_to_json(container_info), &m_inspector->m_meta_evt))
 			{
 				m_inspector->m_meta_evt_pending = true;
