@@ -88,6 +88,7 @@ void sinsp_threadinfo::init()
 	m_lastevent_data = NULL;
 	m_parent_loop_detected = false;
 	m_tty = 0;
+	m_blprogram = NULL;
 }
 
 sinsp_threadinfo::~sinsp_threadinfo()
@@ -296,6 +297,10 @@ void sinsp_threadinfo::add_fd_from_scap(scap_fdinfo *fdi, OUT sinsp_fdinfo_t *re
 			newfdi->set_role_server();
 		}
 		break;
+	case SCAP_FD_FILE_V2:
+		newfdi->m_openflags = fdi->info.regularinfo.open_flags;
+		newfdi->m_name = fdi->info.regularinfo.fname;
+		break;
 	case SCAP_FD_FIFO:
 	case SCAP_FD_FILE:
 	case SCAP_FD_DIRECTORY:
@@ -305,6 +310,7 @@ void sinsp_threadinfo::add_fd_from_scap(scap_fdinfo *fdi, OUT sinsp_fdinfo_t *re
 	case SCAP_FD_EVENT:
 	case SCAP_FD_INOTIFY:
 	case SCAP_FD_TIMERFD:
+	case SCAP_FD_NETLINK:
 		newfdi->m_name = fdi->info.fname;
 
 		if(newfdi->m_name == USER_EVT_DEVICE_NAME)
@@ -359,8 +365,11 @@ void sinsp_threadinfo::init(scap_threadinfo* pi)
 	m_comm = pi->comm;
 	m_exe = pi->exe;
 	set_args(pi->args, pi->args_len);
-	set_env(pi->env, pi->env_len);
-	set_cwd(pi->cwd, (uint32_t)strlen(pi->cwd));
+	if(is_main_thread())
+	{
+		set_env(pi->env, pi->env_len);
+		set_cwd(pi->cwd, (uint32_t)strlen(pi->cwd));
+	}
 	m_flags |= pi->flags;
 	m_flags |= PPM_CL_ACTIVE; // Assume that all the threads coming from /proc are real, active threads
 	m_fdtable.clear();
@@ -492,9 +501,31 @@ void sinsp_threadinfo::set_env(const char* env, size_t len)
 	}
 }
 
-string sinsp_threadinfo::get_env(const string& name) const
+const vector<string>& sinsp_threadinfo::get_env()
 {
-	for(const auto& env_var : m_env)
+	if(is_main_thread())
+	{
+		return m_env;
+	}
+	else
+	{
+		auto mtinfo = get_main_thread();
+		if(mtinfo != nullptr)
+		{
+			return mtinfo->get_env();
+		}
+		else
+		{
+			// it should never happen but provide a safe fallback just in case
+			ASSERT(false);
+			return m_env;
+		}
+	}
+}
+
+string sinsp_threadinfo::get_env(const string& name)
+{
+	for(const auto& env_var : get_env())
 	{
 		if((env_var.length() > name.length()) && (env_var.substr(0, name.length()) == name))
 		{
@@ -868,19 +899,58 @@ sinsp_threadinfo* sinsp_threadinfo::get_main_thread()
 }
 #endif
 
+inline void scpy(char* dst, const char* src, uint32_t maxlen)
+{
+	if(maxlen == 0)
+	{
+		return;
+	}
+
+	while(true)
+	{
+		if(maxlen == 1)
+		{
+			*dst = 0;
+			return;
+		}
+
+		if(*src == 0)
+		{
+			*dst = 0;
+			return;
+		}
+
+		*(dst++) = *(src++);
+		maxlen--;
+	}
+}
+
 void sinsp_threadinfo::args_to_scap(scap_threadinfo* sctinfo)
 {
 	uint32_t alen = SCAP_MAX_ARGS_SIZE;
 	uint32_t tlen = 0;
 	char* dst = sctinfo->args;
 
-	for(auto a : m_args)
+	for(auto it = m_args.begin(); it != m_args.end(); ++it)
 	{
-		uint32_t len = a.size() + 1;
+		uint32_t len = it->size() + 1;
 
-		strncpy(dst + tlen, a.c_str(), alen);
-		tlen += len;
-		alen -= len;
+		scpy(dst + tlen, it->c_str(), alen);
+
+		if(len >= alen) 
+		{
+			//
+			// We saturated the args buffer. Null terminate it and return
+			//
+			sctinfo->args[SCAP_MAX_ARGS_SIZE - 1] = 0;
+			sctinfo->args_len = SCAP_MAX_ARGS_SIZE;
+			return;
+		}
+		else
+		{
+			tlen += len;
+			alen -= len;
+		}
 	}
 
 	sctinfo->args_len = tlen;
@@ -892,13 +962,26 @@ void sinsp_threadinfo::env_to_scap(scap_threadinfo* sctinfo)
 	uint32_t tlen = 0;
 	char* dst = sctinfo->env;
 
-	for(auto a : m_env)
+	for(auto it = m_env.begin(); it != m_env.end(); ++it)
 	{
-		uint32_t len = a.size() + 1;
+		uint32_t len = it->size() + 1;
 
-		strncpy(dst + tlen, a.c_str(), alen);
-		tlen += len;
-		alen -= len;
+		scpy(dst + tlen, it->c_str(), alen);
+
+		if(len >= alen) 
+		{
+			//
+			// We saturated the args buffer. Null terminate it and return
+			//
+			sctinfo->env[SCAP_MAX_ENV_SIZE - 1] = 0;
+			sctinfo->env_len = SCAP_MAX_ENV_SIZE;
+			return;
+		}
+		else
+		{
+			tlen += len;
+			alen -= len;
+		}
 	}
 
 	sctinfo->env_len = tlen;
@@ -910,14 +993,27 @@ void sinsp_threadinfo::cgroups_to_scap(scap_threadinfo* sctinfo)
 	uint32_t tlen = 0;
 	char* dst = sctinfo->cgroups;
 
-	for(auto cg : m_cgroups)
+	for(auto it = m_cgroups.begin(); it != m_cgroups.end(); ++it)
 	{
-		string a = cg.first + "=" + cg.second;
+		string a = it->first + "=" + it->second;
 		uint32_t len = a.size() + 1;
 
-		strncpy(dst + tlen, a.c_str(), alen);
-		tlen += len;
-		alen -= len;
+		scpy(dst + tlen, a.c_str(), alen);
+
+		if(len >= alen) 
+		{
+			//
+			// We saturated the args buffer. Null terminate it and return
+			//
+			sctinfo->cgroups[SCAP_MAX_CGROUPS_SIZE - 1] = 0;
+			sctinfo->cgroups_len = SCAP_MAX_CGROUPS_SIZE;
+			return;
+		}
+		else
+		{
+			tlen += len;
+			alen -= len;
+		}
 	}
 
 	sctinfo->cgroups_len = tlen;
@@ -959,6 +1055,10 @@ void sinsp_threadinfo::fd_to_scap(scap_fdinfo *dst, sinsp_fdinfo_t* src)
 		dst->info.unix_socket_info.destination = src->m_sockinfo.m_unixinfo.m_fields.m_dest;
 		strncpy(dst->info.unix_socket_info.fname, src->m_name.c_str(), SCAP_MAX_PATH_SIZE);
 		break;
+	case SCAP_FD_FILE_V2:
+		dst->info.regularinfo.open_flags = src->m_openflags;
+		strncpy(dst->info.regularinfo.fname, src->m_name.c_str(), SCAP_MAX_PATH_SIZE);
+		break;
 	case SCAP_FD_FIFO:
 	case SCAP_FD_FILE:
 	case SCAP_FD_DIRECTORY:
@@ -968,6 +1068,7 @@ void sinsp_threadinfo::fd_to_scap(scap_fdinfo *dst, sinsp_fdinfo_t* src)
 	case SCAP_FD_EVENT:
 	case SCAP_FD_INOTIFY:
 	case SCAP_FD_TIMERFD:
+	case SCAP_FD_NETLINK:
 		strncpy(dst->info.fname, src->m_name.c_str(), SCAP_MAX_PATH_SIZE);
 		break;
 	default:
@@ -1242,89 +1343,186 @@ void sinsp_thread_manager::update_statistics()
 #endif
 }
 
-void sinsp_thread_manager::to_scap()
+void sinsp_thread_manager::free_dump_fdinfos(vector<scap_fdinfo*>* fdinfos_to_free)
 {
-	scap_proc_free_table(m_inspector->m_h);
+	for(uint32_t j = 0; j < fdinfos_to_free->size(); j++)
+	{
+		free(fdinfos_to_free->at(j));
+	}
+
+	fdinfos_to_free->clear();
+}
+
+void sinsp_thread_manager::thread_to_scap(sinsp_threadinfo& tinfo, 	scap_threadinfo* sctinfo)
+{
+	//
+	// Fill in the thread data
+	//
+	sctinfo->tid = tinfo.m_tid;
+	sctinfo->pid = tinfo.m_pid;
+	sctinfo->ptid = tinfo.m_ptid;
+	sctinfo->sid = tinfo.m_sid;
+
+	strncpy(sctinfo->comm, tinfo.m_comm.c_str(), SCAP_MAX_PATH_SIZE);
+	strncpy(sctinfo->exe, tinfo.m_exe.c_str(), SCAP_MAX_PATH_SIZE);
+	tinfo.args_to_scap(sctinfo);
+	tinfo.env_to_scap(sctinfo);
+	string tcwd = (tinfo.m_cwd == "")? "/": tinfo.m_cwd;
+	strncpy(sctinfo->cwd, tcwd.c_str(), SCAP_MAX_PATH_SIZE);
+	sctinfo->flags = tinfo.m_flags ;
+	sctinfo->fdlimit = tinfo.m_fdlimit;
+	sctinfo->uid = tinfo.m_uid;
+	sctinfo->gid = tinfo.m_gid;
+	sctinfo->vmsize_kb = tinfo.m_vmsize_kb;
+	sctinfo->vmrss_kb = tinfo.m_vmrss_kb;
+	sctinfo->vmswap_kb = tinfo.m_vmswap_kb;
+	sctinfo->pfmajor = tinfo.m_pfmajor;
+	sctinfo->pfminor = tinfo.m_pfminor;
+	sctinfo->vtid = tinfo.m_vtid;
+	sctinfo->vpid = tinfo.m_vpid;
+	sctinfo->fdlist = NULL;
+	tinfo.cgroups_to_scap(sctinfo);
+	strncpy(sctinfo->root, tinfo.m_root.c_str(), SCAP_MAX_PATH_SIZE);
+	sctinfo->filtered_out = false;
+}
+
+void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
+{
+	scap_threadinfo sctinfo;
+
+	//
+	// First pass of the table to calculate the length
+	//
+	uint32_t totlen = 0;
 
 	for(auto it = m_threadtable.begin(); it != m_threadtable.end(); ++it)
 	{
 		sinsp_threadinfo& tinfo = it->second;
 
-		//
-		// Allocate the scap thread info
-		//
-		scap_threadinfo* sctinfo = (scap_threadinfo*)malloc(sizeof(scap_threadinfo));
-		if(sctinfo == NULL)
-		{
-			throw sinsp_exception("memory allocation error in sinsp_thread_manager::to_scap");
-		}
+		tinfo.args_to_scap(&sctinfo);
+		tinfo.env_to_scap(&sctinfo);
+		tinfo.cgroups_to_scap(&sctinfo);
 
-		//
-		// Fill in the thread data
-		//
-		sctinfo->tid = tinfo.m_tid;
-		sctinfo->pid = tinfo.m_pid;
-		sctinfo->ptid = tinfo.m_ptid;
-		sctinfo->sid = tinfo.m_sid;
-
-		strncpy(sctinfo->comm, tinfo.m_comm.c_str(), SCAP_MAX_PATH_SIZE);
-		strncpy(sctinfo->exe, tinfo.m_exe.c_str(), SCAP_MAX_PATH_SIZE);
-		tinfo.args_to_scap(sctinfo);
-		tinfo.env_to_scap(sctinfo);
 		string tcwd = (tinfo.m_cwd == "")? "/": tinfo.m_cwd;
-		strncpy(sctinfo->cwd, tcwd.c_str(), SCAP_MAX_PATH_SIZE);
-		sctinfo->flags = tinfo.m_flags ;
-		sctinfo->fdlimit = tinfo.m_fdlimit;
-		sctinfo->uid = tinfo.m_uid;
-		sctinfo->gid = tinfo.m_gid;
-		sctinfo->vmsize_kb = tinfo.m_vmsize_kb;
-		sctinfo->vmrss_kb = tinfo.m_vmrss_kb;
-		sctinfo->vmswap_kb = tinfo.m_vmswap_kb;
-		sctinfo->pfmajor = tinfo.m_pfmajor;
-		sctinfo->pfminor = tinfo.m_pfminor;
-		sctinfo->vtid = tinfo.m_vtid;
-		sctinfo->vpid = tinfo.m_vpid;
-		sctinfo->fdlist = NULL;
-		tinfo.cgroups_to_scap(sctinfo);
-		strncpy(sctinfo->root, tinfo.m_root.c_str(), SCAP_MAX_PATH_SIZE);
-		sctinfo->filtered_out = false;
 
-		//
-		// Add the FDs
-		//
-		unordered_map<int64_t, sinsp_fdinfo_t>& fdtable = tinfo.get_fd_table()->m_table;
-		for(auto it = fdtable.begin(); it != fdtable.end(); ++it)
+		uint32_t il = (uint32_t)
+			(sizeof(uint64_t) +	// tid
+			sizeof(uint64_t) +	// pid
+			sizeof(uint64_t) +	// ptid
+			sizeof(uint64_t) +	// sid
+			2 + MIN(tinfo.m_comm.size(), SCAP_MAX_PATH_SIZE) +
+			2 + MIN(tinfo.m_exe.size(), SCAP_MAX_PATH_SIZE) +
+			2 + sctinfo.args_len +
+			2 + MIN(tcwd.size(), SCAP_MAX_PATH_SIZE) +
+			sizeof(uint64_t) +	// fdlimit
+			sizeof(uint32_t) +	// uid
+			sizeof(uint32_t) +	// gid
+			sizeof(uint32_t) +  // vmsize_kb
+			sizeof(uint32_t) +  // vmrss_kb
+			sizeof(uint32_t) +  // vmswap_kb
+			sizeof(uint64_t) +  // pfmajor
+			sizeof(uint64_t) +  // pfminor
+			2 + sctinfo.env_len +
+			sizeof(int64_t) +  // vtid
+			sizeof(int64_t) +  // vpid
+			2 + sctinfo.cgroups_len +
+			sizeof(uint32_t) +
+			2 + MIN(tinfo.m_root.size(), SCAP_MAX_PATH_SIZE));
+
+		totlen += il;
+	}
+
+	//
+	// Second pass of the table to dump the Threads
+	//
+	if(scap_write_proclist_header(m_inspector->m_h, dumper, totlen) != SCAP_SUCCESS)
+	{
+		throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
+	}
+
+	for(auto it = m_threadtable.begin(); it != m_threadtable.end(); ++it)
+	{
+		sinsp_threadinfo& tinfo = it->second;
+
+		thread_to_scap(tinfo, &sctinfo);
+
+		if(scap_write_proclist_entry(m_inspector->m_h, dumper, &sctinfo) != SCAP_SUCCESS)
 		{
-			//
-			// Allocate the scap fd info
-			//
-			scap_fdinfo* scfdinfo = (scap_fdinfo*)malloc(sizeof(scap_fdinfo));
-			if(scfdinfo == NULL)
-			{
-				throw sinsp_exception("thread memory allocation error in sinsp_thread_manager::to_scap");
-			}
-
-			//
-			// Populate the fd info
-			//
-			scfdinfo->fd = it->first;
-			tinfo.fd_to_scap(scfdinfo, &it->second);
-
-			//
-			// Add the new fd to the scap table
-			//
-			if(scap_fd_add(sctinfo, it->first, scfdinfo) != SCAP_SUCCESS)
-			{
-				throw sinsp_exception("error calling scap_fd_add in sinsp_thread_manager::to_scap");
-			}
-		}
-
-		//
-		// Add the created info to scap
-		//
-		if(scap_proc_add(m_inspector->m_h, it->second.m_tid, sctinfo) != SCAP_SUCCESS)
-		{
-			throw sinsp_exception("error calling scap_proc_add in sinsp_thread_manager::to_scap");
+			throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
 		}
 	}
+
+	if(scap_write_proclist_trailer(m_inspector->m_h, dumper, totlen) != SCAP_SUCCESS)
+	{
+		throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
+	}
+
+	//
+	// Third pass of the table to dump the FDs
+	//
+	vector<scap_fdinfo*>* fdinfos_to_free = new vector<scap_fdinfo*>();
+
+	for(auto it = m_threadtable.begin(); it != m_threadtable.end(); ++it)
+	{
+		sinsp_threadinfo& tinfo = it->second;
+
+		thread_to_scap(tinfo, &sctinfo);
+
+		fdinfos_to_free->clear();
+
+
+		if(tinfo.is_main_thread())
+		{
+			//
+			// Add the FDs
+			//
+			unordered_map<int64_t, sinsp_fdinfo_t>& fdtable = tinfo.get_fd_table()->m_table;
+			for(auto it = fdtable.begin(); it != fdtable.end(); ++it)
+			{
+				//
+				// Allocate the scap fd info
+				//
+				scap_fdinfo* scfdinfo = (scap_fdinfo*)malloc(sizeof(scap_fdinfo));
+				if(scfdinfo == NULL)
+				{
+					free_dump_fdinfos(fdinfos_to_free);
+					delete fdinfos_to_free;
+					throw sinsp_exception("thread memory allocation error in sinsp_thread_manager::to_scap");
+				}
+
+				fdinfos_to_free->push_back(scfdinfo);
+
+				//
+				// Populate the fd info
+				//
+				scfdinfo->fd = it->first;
+				tinfo.fd_to_scap(scfdinfo, &it->second);
+
+				//
+				// Add the new fd to the scap table
+				//
+				if(scap_fd_add(&sctinfo, it->first, scfdinfo) != SCAP_SUCCESS)
+				{
+					free_dump_fdinfos(fdinfos_to_free);
+					delete fdinfos_to_free;
+					throw sinsp_exception("error calling scap_fd_add in sinsp_thread_manager::to_scap");
+				}
+			}
+		}
+
+		//
+		// Dump the thread to disk
+		//
+		if(scap_write_proc_fds(m_inspector->m_h, &sctinfo, dumper) != SCAP_SUCCESS)
+		{
+			free_dump_fdinfos(fdinfos_to_free);
+			delete fdinfos_to_free;
+			throw sinsp_exception("error calling scap_proc_add in sinsp_thread_manager::to_scap");
+		}
+
+		free_dump_fdinfos(fdinfos_to_free);
+	}
+
+	free_dump_fdinfos(fdinfos_to_free);
+	delete fdinfos_to_free;
 }
